window.Gleam.initSearch([{"doc":"glitr_lustre","title":"glitr_lustre","content":"# glitr_lustre\n\nInterface for lustre to use Glitr&#39;s typed routes\n\n[![Package Version](https://img.shields.io/hexpm/v/glitr_lustre)](https://hex.pm/packages/glitr_lustre)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glitr_lustre/)\n\n```sh\ngleam add glitr_lustre\n```\n```gleam\nimport glitr_lustre\nimport gleam/http\nimport lustre\nimport lustre/effect\n\npub fn main() {\n  let app = lustre.application(init, update, view)\n  let assert Ok(_) = lustre.start(app, &quot;#app&quot;, Nil)\n\n  Nil\n}\n\nfn update(model: Model, msg: Msg) -&gt; #(Model, Effect(Msg)) {\n  case msg {\n    TodoAdded(title) -&gt; #(model, glitr_lustre.create_factory()\n      |&gt; glitr_lustre.with_scheme(http.Http)\n      |&gt; glitr_lustre.with_host(&quot;localhost&quot;)\n      |&gt; glitr_lustre.with_port(2345)\n      |&gt; glitr_lustre.for_route(todo_service() |&gt; create_route)\n      |&gt; glitr_lustre.with_path(Nil) // Required, for now\n      |&gt; glitr_lustre.with_body(CreateTodo(title))\n      |&gt; glitr_lustre.send(ServerCreatedTodo, fn(_) { effect.none() })\n    )\n    ServerCreatedTodo(Ok(new_todo)) -&gt; #([new_todo, ..model], effect.none())\n    _ -&gt; #(model, effect.none())\n  }\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glitr_lustre&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"glitr/lustre","title":"RequestFactory","content":"pub opaque type RequestFactory\n\n\nSynonyms:\nglitr/lustre.RequestFactory\nglitr/lustre RequestFactory","url":"glitr/lustre.html#RequestFactory"},{"doc":"glitr/lustre","title":"RouteRequest","content":"pub opaque type RouteRequest(p, q, b, c)\n A RouteRequest contains the data required to send a request to a backend  \n This data contains a route, all the data from the factory that created the request\n as well as path, query and body data that will have to be provided\n\nSynonyms:\nglitr/lustre.RouteRequest\nglitr/lustre RouteRequest","url":"glitr/lustre.html#RouteRequest"},{"doc":"glitr/lustre","title":"create_factory","content":"pub fn create_factory() -&gt; RequestFactory\n Create a new default factory  \n By default, it points to &quot;http://localhost:80&quot;\nSynonyms:\nglitr/lustre.create_factory\nglitr/lustre create_factory","url":"glitr/lustre.html#create_factory"},{"doc":"glitr/lustre","title":"for_route","content":"pub fn for_route(\n  factory: RequestFactory,\n  route: Route(a, b, c, d),\n) -&gt; RouteRequest(a, b, c, d)\n Create a RouteRequest given a RequestFactory and a Route\nSynonyms:\nglitr/lustre.for_route\nglitr/lustre for_route","url":"glitr/lustre.html#for_route"},{"doc":"glitr/lustre","title":"send","content":"pub fn send(\n  rreq: RouteRequest(a, b, c, d),\n  as_msg: fn(Result(d, HttpError)) -&gt; e,\n  on_error: fn(String) -&gt; Effect(e),\n) -&gt; Effect(e)\n Send a RouteRequest and handle the result  \n Uses lustre_http under the hood to send the result, catch the response and transform the data\nSynonyms:\nglitr/lustre.send\nglitr/lustre send","url":"glitr/lustre.html#send"},{"doc":"glitr/lustre","title":"with_body","content":"pub fn with_body(\n  request: RouteRequest(a, b, c, d),\n  body: c,\n) -&gt; RouteRequest(a, b, c, d)\n Set the body data for this request\nSynonyms:\nglitr/lustre.with_body\nglitr/lustre with_body","url":"glitr/lustre.html#with_body"},{"doc":"glitr/lustre","title":"with_host","content":"pub fn with_host(\n  factory: RequestFactory,\n  host: String,\n) -&gt; RequestFactory\n Changes the host of a RequestFactory\nSynonyms:\nglitr/lustre.with_host\nglitr/lustre with_host","url":"glitr/lustre.html#with_host"},{"doc":"glitr/lustre","title":"with_options","content":"pub fn with_options(\n  request: RouteRequest(a, b, c, d),\n  options: RouteOptions(a, b, c),\n) -&gt; RouteRequest(a, b, c, d)\n Set the path, query and body data all at the same time\nSynonyms:\nglitr/lustre.with_options\nglitr/lustre with_options","url":"glitr/lustre.html#with_options"},{"doc":"glitr/lustre","title":"with_path","content":"pub fn with_path(\n  request: RouteRequest(a, b, c, d),\n  path: a,\n) -&gt; RouteRequest(a, b, c, d)\n Set the path data for this request  \n Note that, for now, you have to call this method before sending the request\nSynonyms:\nglitr/lustre.with_path\nglitr/lustre with_path","url":"glitr/lustre.html#with_path"},{"doc":"glitr/lustre","title":"with_port","content":"pub fn with_port(\n  factory: RequestFactory,\n  port: Int,\n) -&gt; RequestFactory\n Changes the port of a RequestFactory\nSynonyms:\nglitr/lustre.with_port\nglitr/lustre with_port","url":"glitr/lustre.html#with_port"},{"doc":"glitr/lustre","title":"with_query","content":"pub fn with_query(\n  request: RouteRequest(a, b, c, d),\n  query: b,\n) -&gt; RouteRequest(a, b, c, d)\n Set the query data for this request\nSynonyms:\nglitr/lustre.with_query\nglitr/lustre with_query","url":"glitr/lustre.html#with_query"},{"doc":"glitr/lustre","title":"with_scheme","content":"pub fn with_scheme(\n  factory: RequestFactory,\n  scheme: Scheme,\n) -&gt; RequestFactory\n Changes the scheme of a RequestFactory  \n Also sets the port to the default for the selected scheme (80 for http and 443 for https)\nSynonyms:\nglitr/lustre.with_scheme\nglitr/lustre with_scheme","url":"glitr/lustre.html#with_scheme"},{"doc":"glitr/lustre","title":"glitr/lustre","content":" This module helps to make the bridge between glitr Routes and lustre","url":"glitr/lustre.html"},{"doc":"glitr_lustre","title":"glitr_lustre","content":"","url":"glitr_lustre.html"}]);